class CorpusList extends List {
  constructor(idOrElement, options) {
    super(idOrElement, options);
    corporaSubscribers.push(this);
  }


  _init() {
    for (let [id, corpus] of Object.entries(corpora)) {
      this.addCorpus(corpus);
    }

    this.update()
    List.updatePagination(this);
  }


  _update(patch) {
    var item, operation, pathArray;

    for (operation of patch) {
      /* "/corpusId/valueName" -> ["corpusId", "valueName"] */
      pathArray = operation.path.split("/").slice(1);
      switch(operation.op) {
        case "add":
          this.addCorpus(operation.value);
          this.update()
          List.updatePagination(this);
          break;
        case "remove":
          this.remove("id", pathArray[0]);
          List.updatePagination(this);
          break;
        case "replace":
          item = this.get("id", pathArray[0])[0];
          switch(pathArray[1]) {
            case "description":
              item.values({"description": operation.value});
              break;
            case "title":
              item.values({"title": operation.value});
              break;
            default:
              break;
          }
        default:
          break;
      }
    }
  }


  addCorpus(corpus) {
    var corpusDescriptionElement, corpusElement, corpusIconElement,
        corpusTitleElement;

    corpusDescriptionElement = document.createElement("p");
    corpusDescriptionElement.classList.add("description");
    corpusDescriptionElement.innerText = corpus.description;
    corpusElement = document.createElement("a");
    corpusElement.classList.add("avatar", "collection-item");
    corpusElement.dataset.id = corpus.id;
    corpusElement.href = `/corpora/${corpus.id}`;
    corpusIconElement = document.createElement("i");
    corpusIconElement.classList.add("circle", "material-icons");
    corpusIconElement.innerText = "book";
    corpusTitleElement = document.createElement("span");
    corpusTitleElement.classList.add("title");
    corpusTitleElement.dataset.key = "title";
    corpusTitleElement.innerText = corpus.title;

    corpusElement.appendChild(corpusIconElement);
    corpusElement.appendChild(corpusTitleElement);
    corpusElement.appendChild(corpusDescriptionElement);

    this.add(
      [{description: corpus.description, id: corpus.id, title: corpus.title}],
      function(items) {items[0].elm = corpusElement;}
    );
  }
}
